#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from functools import partial
from ...config import custom_scalars, datetime
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional

from dataclasses_json import DataClassJsonMixin, config

from ..input.equipment_port_input import EquipmentPortInput
from ..input.equipment_position_input import EquipmentPositionInput
from ..input.property_type_input import PropertyTypeInput


@dataclass(frozen=True)
class AddEquipmentTypeInput(DataClassJsonMixin):
    name: str
    positions: List[EquipmentPositionInput]
    ports: List[EquipmentPortInput]
    properties: List[PropertyTypeInput]
    category: Optional[str] = None



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from enum import Enum


class CheckListItemEnumSelectionMode(Enum):
    single = "single"
    multiple = "multiple"
    MISSING_ENUM = ""

    @classmethod
    def _missing_(cls, value: object) -> "CheckListItemEnumSelectionMode":
        return cls.MISSING_ENUM



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import Dict, Iterator, List, Optional

from psym.client import SymphonyClient
from psym.common.cache import PORT_TYPES
from psym.common.data_class import EquipmentPortType, PropertyDefinition, PropertyValue
from psym.common.data_enum import Entity
from psym.common.data_format import (
    format_to_equipment_port_type,
    format_to_property_type_inputs,
)

from .._utils import get_graphql_property_type_inputs
from ..exceptions import EntityNotFoundError
from ..graphql.input.add_equipment_port_type_input import AddEquipmentPortTypeInput
from ..graphql.input.edit_equipment_port_type_input import EditEquipmentPortTypeInput
from ..graphql.mutation.add_equipment_port_type import AddEquipmentPortTypeMutation
from ..graphql.mutation.edit_equipment_port_type import EditEquipmentPortTypeMutation
from ..graphql.mutation.remove_equipment_port_type import (
    RemoveEquipmentPortTypeMutation,
)
from ..graphql.query.equipment_port_type import EquipmentPortTypeQuery
from ..graphql.query.equipment_port_types import EquipmentPortTypesQuery


def _populate_equipment_port_types(client: SymphonyClient) -> None:
    edges = EquipmentPortTypesQuery.execute(client).edges

    for edge in edges:
        node = edge.node
        if node:
            PORT_TYPES[node.name] = format_to_equipment_port_type(
                equipment_port_type_fragment=node
            )


def add_equipment_port_type(
    client: SymphonyClient,
    name: str,
    properties: List[PropertyDefinition],
    link_properties: List[PropertyDefinition],
) -> EquipmentPortType:
    """This function creates an equipment port type.

    :param name: Equipment port type name
    :type name: str
    :param properties: List of property definitions
    :type properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ])
    :param link_properties: List of property definitions
    :type link_properties: List[ :class:`~psym.common.data_class.PropertyDefinition` ])

    :raises:
        FailedOperationException: Internal symphony error

    :return: EquipmentPortType object
    :rtype: :class:`~psym.common.data_class.EquipmentPortType`

    **Example**

    .. code-block:: python

        from psym.common.data_class import PropertyDefinition
        from psym.graphql.enum.property_kind import PropertyKind
        port_type1 = client.add_equipment_port_type(
            name="port type 1",
            properties=[
                PropertyDefinition(
                    property_name="port property",
                    property_kind=PropertyKind.string,
                    default_raw_value=None,
                    is_fixed=True
                )
            ],
            link_properties=[
                PropertyDefinition(
                    property_name="link port property",
                    property_kind=PropertyKind.string,
                    default_raw_value=None,
                    is_fixed=True
                )
            ],
        )
    """

    formated_property_types = format_to_property_type_inputs(data=properties)
    formated_link_property_types = format_to_property_type_inputs(data=link_properties)
    result = AddEquipmentPortTypeMutation.execute(
        client,
        AddEquipmentPortTypeInput(
            name=name,
            properties=formated_property_types,
            linkProperties=formated_link_property_types,
        ),
    )

    added = format_to_equipment_port_type(equipment_port_type_fragment=result)
    PORT_TYPES[added.name] = added
    return added


def get_equipment_port_type(
    client: SymphonyClient, equipment_port_type_id: str
) -> EquipmentPortType:
    """This function returns an equipment port type.
    It gets the requested equipment port type ID

    :param equipment_port_type_id: Equipment port type ID
    :type equipment_port_type_id: str

    :raises:
        :class:`~psym.exceptions.EntityNotFoundError`: Equipment port type does not found

    :return: EquipmentPortType object
    :rtype: :class:`~psym.common.data_class.EquipmentPortType`

    **Example**

    .. code-block:: python

        port_type = client.get_equipment_port_type(equipment_port_type_id=port_type1.id)
    """
    result = EquipmentPortTypeQuery.execute(client, id=equipment_port_type_id)
    if not result:
        raise EntityNotFoundError(
            entity=Entity.EquipmentPortType, entity_id=equipment_port_type_id
        )

    return format_to_equipment_port_type(equipment_port_type_fragment=result)


def get_equipment_port_types(client: SymphonyClient) -> Iterator[EquipmentPortType]:
    """Get the iterator of equipment port types

    :raises:
        FailedOperationException: Internal symphony error

    :return: EquipmentPortType Iterator
    :rtype: Iterator[ :class:`~psym.common.data_class.EquipmentPortType` ]

    **Example**

    .. code-block:: python

        equipment_port_types = client.get_equipment_port_types()
        for equipment_port_type in equipment_port_types:
            print(equipment_port_type.name)
    """
    result = EquipmentPortTypesQuery.execute(client)
    if result is None:
        return
    for edge in result.edges:
        node = edge.node
        if node is not None:
            yield format_to_equipment_port_type(equipment_port_type_fragment=node)


def edit_equipment_port_type(
    client: SymphonyClient,
    port_type: EquipmentPortType,
    new_name: Optional[str] = None,
    new_properties: Optional[Dict[str, PropertyValue]] = None,
    new_link_properties: Optional[Dict[str, PropertyValue]] = None,
) -> EquipmentPortType:
    """This function edits an existing equipment port type.

    :param port_type: Existing eqipment port type object
    :type port_type: :class:`~psym.common.data_class.EquipmentPortType`
    :param new_name: New name
    :type new_name: str
    :param new_properties: Dictionary of property name to property value

        * str - property name
        * PropertyValue - new value of the same type for this property

    :type new_properties: Dict[str, PropertyValue], optional
    :param new_link_properties: Dictionary of property name to property value

        * str - property name
        * PropertyValue - new value of the same type for this property

    :type new_link_properties: Dict[str, PropertyValue], optional

    :raises:
        FailedOperationException: Internal symphony error

    :return: EquipmentPortType object
    :rtype: :class:`~psym.common.data_class.EquipmentPortType`

    **Example**

    .. code-block:: python

        port_type1 = client.edit_equipment_port_type(
            port_type=equipment_port_type,
            new_name="new port type name",
            new_properties={"existing property name": "new value"},
            new_link_properties={"existing link property name": "new value"},
        )
    """
    new_name = port_type.name if new_name is None else new_name

    new_property_type_inputs = []
    if new_properties:
        property_types = PORT_TYPES[port_type.name].property_types
        new_property_type_inputs = get_graphql_property_type_inputs(
            property_types, new_properties
        )

    new_link_property_type_inputs = []
    if new_link_properties:
        link_property_types = PORT_TYPES[port_type.name].link_property_types
        new_link_property_type_inputs = get_graphql_property_type_inputs(
            link_property_types, new_link_properties
        )

    result = EditEquipmentPortTypeMutation.execute(
        client,
        EditEquipmentPortTypeInput(
            id=port_type.id,
            name=new_name,
            properties=new_property_type_inputs,
            linkProperties=new_link_property_type_inputs,
        ),
    )
    edited = format_to_equipment_port_type(equipment_port_type_fragment=result)
    PORT_TYPES.pop(port_type.name)
    PORT_TYPES[edited.name] = edited
    return edited


def delete_equipment_port_type(
    client: SymphonyClient, equipment_port_type_id: str
) -> None:
    """This function deletes an equipment port type.
    It gets the requested equipment port type ID

    :param equipment_port_type_id: Equipment port type ID
    :type equipment_port_type_id: str

    :raises:
        * FailedOperationException: Internal symphony error
        * :class:`~psym.exceptions.EntityNotFoundError`: Equipment port type does not exist

    **Example**

    .. code-block:: python

        client.delete_equipment_port_type(
            equipment_port_type_id="12345678"
        )
    """
    port_type = get_equipment_port_type(
        client=client, equipment_port_type_id=equipment_port_type_id
    )
    if port_type is None:
        raise EntityNotFoundError(
            entity=Entity.EquipmentPortType, entity_id=equipment_port_type_id
        )
    RemoveEquipmentPortTypeMutation.execute(client, id=equipment_port_type_id)
    del PORT_TYPES[port_type.name]



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from ...config import custom_scalars, datetime
from gql_client.runtime.variables import encode_variables
from gql import gql, Client
from gql.transport.exceptions import TransportQueryError
from functools import partial
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional
from time import perf_counter
from dataclasses_json import DataClassJsonMixin, config

from .survey_question import SurveyQuestionFragment, QUERY as SurveyQuestionFragmentQuery

# fmt: off
QUERY: List[str] = SurveyQuestionFragmentQuery + ["""
fragment SurveyFragment on Survey {
  id
  name
  completionTimestamp
  sourceFile {
    id
    fileName
    storeKey
  }
  surveyResponses {
    ...SurveyQuestionFragment
  }
}

"""]

@dataclass(frozen=True)
class SurveyFragment(DataClassJsonMixin):
    @dataclass(frozen=True)
    class File(DataClassJsonMixin):
        id: str
        fileName: str
        storeKey: Optional[str]

    @dataclass(frozen=True)
    class SurveyQuestion(SurveyQuestionFragment):
        pass

    id: str
    name: str
    completionTimestamp: int
    sourceFile: Optional[File]
    surveyResponses: List[SurveyQuestion]



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from ...config import custom_scalars, datetime
from gql_client.runtime.variables import encode_variables
from gql import gql, Client
from gql.transport.exceptions import TransportQueryError
from functools import partial
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional
from time import perf_counter
from dataclasses_json import DataClassJsonMixin, config

from .property import PropertyFragment, QUERY as PropertyFragmentQuery

from gql_client.runtime.enum_utils import enum_field_metadata
from ..enum.work_order_priority import WorkOrderPriority
from ..enum.work_order_status import WorkOrderStatus

# fmt: off
QUERY: List[str] = PropertyFragmentQuery + ["""
fragment WorkOrderFragment on WorkOrder {
    id
    name
    description
    workOrderType{
        id
        name
    }
    location{
        id
    }
    project{
        id
    }
    properties{
        ...PropertyFragment
    }
    owner{
        id
    }
    assignedTo{
        id
    }
    organizationFk{
        id
    }
    status
    priority
}
"""]

@dataclass(frozen=True)
class WorkOrderFragment(DataClassJsonMixin):
    @dataclass(frozen=True)
    class WorkOrderType(DataClassJsonMixin):
        id: str
        name: str

    @dataclass(frozen=True)
    class Location(DataClassJsonMixin):
        id: str

    @dataclass(frozen=True)
    class Project(DataClassJsonMixin):
        id: str

    @dataclass(frozen=True)
    class Property(PropertyFragment):
        pass

    @dataclass(frozen=True)
    class User(DataClassJsonMixin):
        id: str

    @dataclass(frozen=True)
    class Organization(DataClassJsonMixin):
        id: str

    id: str
    name: str
    description: Optional[str]
    workOrderType: WorkOrderType
    location: Optional[Location]
    project: Optional[Project]
    properties: List[Property]
    owner: User
    assignedTo: Optional[User]
    organizationFk: Optional[Organization]
    status: WorkOrderStatus = _field(metadata=enum_field_metadata(WorkOrderStatus))
    priority: WorkOrderPriority = _field(metadata=enum_field_metadata(WorkOrderPriority))



#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from ...config import custom_scalars, datetime
from gql_client.runtime.variables import encode_variables
from gql import gql, Client
from gql.transport.exceptions import TransportQueryError
from functools import partial
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional
from time import perf_counter
from dataclasses_json import DataClassJsonMixin, config

from gql_client.runtime.enum_utils import enum_field_metadata
from ..enum.property_kind import PropertyKind

# fmt: off
QUERY: List[str] = ["""
fragment PropertyTypeFragment on PropertyType {
  id
  externalId
  name
  type
  index
  category
  rawValue
  isEditable
  isInstanceProperty
  isMandatory
  isDeleted
}

"""]

@dataclass(frozen=True)
class PropertyTypeFragment(DataClassJsonMixin):
    id: str
    externalId: Optional[str]
    name: str
    type: PropertyKind = _field(metadata=enum_field_metadata(PropertyKind))
    index: Optional[int]
    category: Optional[str]
    rawValue: Optional[str]
    isEditable: Optional[bool]
    isInstanceProperty: Optional[bool]
    isMandatory: Optional[bool]
    isDeleted: Optional[bool]



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from datetime import datetime, timedelta, tzinfo, timezone
from gql_client.compiler.renderer_dataclasses import CustomScalar

from typing import Dict, Optional, Tuple
from marshmallow import fields as marshmallow_fields


class simple_utc(tzinfo):
    def tzname(self, dt: Optional[datetime]) -> Optional[str]:
        return "UTC"

    def utcoffset(self, dt: Optional[datetime]) -> Optional[timedelta]:
        return timedelta(0)


def isoformat(time: datetime) -> str:
    return datetime.isoformat(time.replace(tzinfo=simple_utc()))


# Helpers for parsing the result of isoformat()
def _parse_isoformat_date(dtstr: str) -> Tuple[int, int, int]:
    # It is assumed that this function will only be called with a
    # string of length exactly 10, and (though this is not used) ASCII-only
    year = int(dtstr[0:4])
    if dtstr[4] != "-":
        raise ValueError("Invalid date separator: %s" % dtstr[4])

    month = int(dtstr[5:7])

    if dtstr[7] != "-":
        raise ValueError("Invalid date separator")

    day = int(dtstr[8:10])

    return (year, month, day)


def _parse_hh_mm_ss_ff(tstr: str) -> Tuple[int, int, int, int]:
    # Parses things of the form HH[:MM[:SS[.fff[fff]]]]
    len_str = len(tstr)

    time_comps = [0, 0, 0, 0]
    pos = 0
    for comp in range(0, 3):
        if (len_str - pos) < 2:
            raise ValueError("Incomplete time component")

        time_comps[comp] = int(tstr[pos : pos + 2])

        pos += 2
        next_char = tstr[pos : pos + 1]

        if not next_char or comp >= 2:
            break

        if next_char != ":":
            raise ValueError("Invalid time separator: %c" % next_char)

        pos += 1

    if pos < len_str:
        if tstr[pos] != ".":
            raise ValueError("Invalid microsecond component")
        else:
            pos += 1

            len_remainder = len_str - pos
            if len_remainder not in (3, 6):
                raise ValueError("Invalid microsecond component")

            time_comps[3] = int(tstr[pos:])
            if len_remainder == 3:
                time_comps[3] *= 1000

    return (time_comps[0], time_comps[1], time_comps[2], time_comps[3])


def _parse_isoformat_time(tstr: str) -> Tuple[int, int, int, int, Optional[tzinfo]]:
    # Format supported is HH[:MM[:SS[.fff[fff]]]][+HH:MM[:SS[.ffffff]]]
    len_str = len(tstr)
    if len_str < 2:
        raise ValueError("Isoformat time too short")

    # This is equivalent to re.search('[+-]', tstr), but faster
    tz_pos = tstr.find("-") + 1 or tstr.find("+") + 1
    timestr = tstr[: tz_pos - 1] if tz_pos > 0 else tstr

    time_comps = _parse_hh_mm_ss_ff(timestr)

    tzi = None
    if tz_pos > 0:
        tzstr = tstr[tz_pos:]

        # Valid time zone strings are:
        # HH:MM               len: 5
        # HH:MM:SS            len: 8
        # HH:MM:SS.ffffff     len: 15

        if len(tzstr) not in (5, 8, 15):
            raise ValueError("Malformed time zone string")

        tz_comps = _parse_hh_mm_ss_ff(tzstr)
        if all(x == 0 for x in tz_comps):
            tzi = timezone.utc
        else:
            tzsign = -1 if tstr[tz_pos - 1] == "-" else 1

            td = timedelta(
                hours=tz_comps[0],
                minutes=tz_comps[1],
                seconds=tz_comps[2],
                microseconds=tz_comps[3],
            )

            tzi = timezone(tzsign * td)

    return (*time_comps, tzi)


def fromisoformat(date_string: str) -> datetime:
    """Construct a datetime from the output of datetime.isoformat()."""
    if not isinstance(date_string, str):
        raise TypeError("fromisoformat: argument must be str")

    # Split this at the separator
    dstr = date_string[0:10]
    tstr = date_string[11:]

    try:
        date_components = _parse_isoformat_date(dstr)
    except ValueError:
        raise ValueError(f"Invalid isoformat string: {date_string!r}")

    if tstr:
        try:
            time_components = _parse_isoformat_time(tstr)
        except ValueError:
            raise ValueError(f"Invalid isoformat string: {date_string!r}")
    else:
        time_components = (0, 0, 0, 0, None)

    return datetime(*(date_components + time_components))


custom_scalars: Dict[str, CustomScalar] = {
    "Time": CustomScalar(
        name="Time",
        type=datetime,
        encoder=isoformat,
        decoder=fromisoformat,
        mm_field=marshmallow_fields.DateTime(format="iso"),
    ),
    "Cursor": CustomScalar(
        name="Cursor",
        type=str,
    ),
}



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import comparator

from ..graphql.input.edit_comparator_input import EditComparatorInput
from ..graphql.input.add_comparator_input import AddComparatorInput
from ..graphql.mutation.add_comparator import addComparator
from ..graphql.mutation.edit_comparator import editComparator
from ..graphql.mutation.remove_comparator import removeComparator
from ..graphql.query.comparators import comparators
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_comparator(
    client: SymphonyClient, name: str
) -> comparator:
    """This function adds Comparator.

    :param name: Comparator name
    :type name: str

    :return: comparator object
    :rtype: :class:`~psym.common.data_class.comparator`

    **Example 1**

    .. code-block:: python

        new_comparator = client.add_comparator(
            name="comparator",
        )
        print(new_comparator)
    """ 
    comparator_input = AddComparatorInput(name=name)
    if (len(name) != 0):
        result = addComparator.execute(client, input=comparator_input)
        return comparator(name=result.name, id=result.id)
    else:
        print ("you cant leave the name parameter empty")

def edit_comparator(
    client: SymphonyClient,
    comparator: comparator,
    new_name: Optional[str] = None,
) -> None:
    """This function edits Comparator.

    :param comparator: Comparator entity
    :type name: str
    :param new_name: Comparator name
    :type name: str

    :return: none object
    :rtype: :class:`~psym.common.data_class.comparator`

    **Example 1**

    .. code-block:: python

        comparator_edited = client.edit_comparator(
        comparator=new_comparator,
        new_name="comparator_edited",
                )
        print(comparator_edited)    
    """
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editComparator.execute(client, input=EditComparatorInput(id=comparator.id, name=new_name))

def get_comparators(client: SymphonyClient) -> Iterator[comparator]:

    """ this funtion Get Comparators


    :return: comparator object
    :rtype: Iterator[ :class:`~psym.common.data_class.comparator` ]

    **Example**

    .. code-block:: python

        comparators = client.get_comparators()
        for comparator in comparators:
            print(comparator.name)
    """
    comparators_ = comparators.execute(client, first=PAGINATION_STEP)
    edges = comparators_.edges if comparators_ else []
    while comparators_ is not None and comparators_.pageInfo.hasNextPage:
        comparators_ = comparators.execute(
            client, after=comparators_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if comparators_ is not None:
            edges.extend(comparators_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield comparator(
                id=node.id,
                name=node.name,
            )


def remove_comparator(client: SymphonyClient, id: str) -> None:
    """This function delete comparator.

    :param name: comparator name
    :type name: :class:`~psym.common.data_class.comparator`
    :rtype: None

    **Example**

    .. code-block:: python

        remove_comparator=client.remove_comparator(id=123456789)
    """
    removeComparator.execute(client, id=id)



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import ruleType

from ..graphql.input.edit_event_severity_input import EditEventSeverityInput
from ..graphql.input.add_event_severity_input import AddEventSeverityInput
from ..graphql.mutation.add_event_severity import addEventSeverity
from ..graphql.mutation.edit_event_severity import editEventSeverity
from ..graphql.mutation.remove_event_severity import removeEventSeverity
from ..graphql.query.eventSeverities import eventSeverities
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_event_severity(
    client: SymphonyClient, name: str
) -> ruleType:
    """This function adds Event Severity.

    :param name: Event Severity name
    :type name: str

    :return: eventSeverity object
    :rtype: :class:`~psym.common.data_class.eventSeverity`

    **Example 1**

    .. code-block:: python

        new_event_severity = client.add_event_severity(
            name="event_severity",
        )
        print(new_event_severity)
    """
    event_severity_input = AddEventSeverityInput(name=name)
    if (len(name) != 0):
        result = addEventSeverity.execute(client, input=event_severity_input)
        return ruleType(name=result.name, id=result.id)
    else:
        print ("you cant leave the name parameter empty")

def edit_event_severity(
    client: SymphonyClient,
    event_severity: ruleType,
    new_name: Optional[str] = None,
) -> None:
    """This function edits Event Severity.

    :param event_severity: Event Severity entity
    :type name: str
    :param new_name: Event Severity name
    :type name: str

    :return: none object
    :rtype: :class:`~psym.common.data_class.eventSeverity`

    **Example 1**

    .. code-block:: python

        new_event_severity = client.edit_event_severity(
            event_severity=new_event_severity,
            new_name="event_severity_edited",

        )
    """
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        editEventSeverity.execute(client, input=EditEventSeverityInput(id=event_severity.id, name=new_name))

def get_event_severities(client: SymphonyClient) -> Iterator[ruleType]:
    """ this funtion Get Event Severities


    :return: eventSeverity object
    :rtype: Iterator[ :class:`~psym.common.data_class.eventSeverity` ]

    **Example**

    .. code-block:: python

        event_severities = client.get_event_severities()
        for event_severity in event_severities:
            print(event_severity.name)
    """
    event_severitys_ = eventSeverities.execute(client, first=PAGINATION_STEP)
    edges = event_severitys_.edges if event_severitys_ else []
    while event_severitys_ is not None and event_severitys_.pageInfo.hasNextPage:
        event_severitys_ = eventSeverities.execute(
            client, after=event_severitys_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if event_severitys_ is not None:
            edges.extend(event_severitys_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield ruleType(
                id=node.id,
                name=node.name,
            )


def remove_event_severity(client: SymphonyClient, id: str) -> None:
    """This function delete Event Severity.

    :param name: Event Severity name
    :type name: :class:`~psym.common.data_class.eventSeverity`
    :rtype: None

    **Example**

    .. code-block:: python

        client.remove_event_severity(id=123456789)
    """
    removeEventSeverity.execute(client, id=id)





#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from enum import Enum


class SurveyStatus(Enum):
    PLANNED = "PLANNED"
    INPROGRESS = "INPROGRESS"
    COMPLETED = "COMPLETED"
    MISSING_ENUM = ""

    @classmethod
    def _missing_(cls, value: object) -> "SurveyStatus":
        return cls.MISSING_ENUM



#!/usr/bin/env python3
# Copyright (c) 2004-present Facebook All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.


from psym.client import SymphonyClient
from psym.common.data_class import alarmStatus
from psym.common.data_enum import Entity
from psym.exceptions import EntityNotFoundError

from ..graphql.input.edit_alarm_status_input import EditAlarmStatusInput
from ..graphql.input.add_alarm_status_input import AddAlarmStatusInput
from ..graphql.mutation.add_alarm_status import addAlarmStatus
from ..graphql.mutation.edit_alarm_status import editAlarmStatus
from ..graphql.mutation.remove_alarm_status import removeAlarmStatus
from ..graphql.query.alarm_statuses import alarmStatuses
from psym.common.constant import PAGINATION_STEP
from typing import Any, Dict, Iterator, List, Optional




def add_alarm_status(
    client: SymphonyClient, name: str
) -> alarmStatus:
    """This function adds Alarm Status.

    :param name: Alarm Status name
    :type name: str

    :return: alarmStatus object
    :rtype: :class:`~psym.common.data_class.alarmStatus`

    **Example 1**

    .. code-block:: python

        new_alarm_statuses = client.add_alarm_status(name="new_alarm_status")

    **Example 2**

    .. code-block:: python

        new_alarm_status = client.add_alarm_status(
            name="alarm_status",
        )
        print(new_alarm_status)
    """
    alarm_status_input = AddAlarmStatusInput(name=name)
    if (name is None):
        print ("you cant leave the name parameter empty and must be a text")
    if (name!=str):
        print ("you cant leave the name parameter empty and must be a text")
    else:
        result = addAlarmStatus.execute(client, input=alarm_status_input)
        return alarmStatus(name=result.name, id=result.id)


def edit_alarm_status(
    client: SymphonyClient,
    alarm_status: alarmStatus,
    new_name: Optional[str] = None,
) -> None:
    """This function edits Alarm Status.

    :param alarm_status: Alarm Status entity
    :type name: str
    :param new_name: Alarm Status name
    :type name: str

    :return: none object
    :rtype: :class:`~psym.common.data_class.alarmStatus`

    **Example 1**

    .. code-block:: python

        alarm_status_edited = client.edit_alarm_status(alarm_status=alarmStatus ,new_name="new_alarm_status")

    **Example 2**

    .. code-block:: python

        new_alarm_status = client.edit_alarm_status(
            alarm_status=alarmStatus,
            new_name="alarm_status",

        )
    """
    params: Dict[str, Any] = {}
    if new_name is not None:
        params.update({"_name_": new_name})
    if new_name is not None:
        result=editAlarmStatus.execute(client, input=EditAlarmStatusInput(id=alarm_status.id, name=new_name))
    return alarmStatus(name=result.name, id=result.id)

def get_alarm_statuses(client: SymphonyClient) -> Iterator[alarmStatus]:
    """ this funtion Get Alarm statuses


    :return: alarmStatus object
    :rtype: Iterator[ :class:`~psym.common.data_class.alarmStatus` ]

    **Example**

    .. code-block:: python

        alarm_statuses = client.get_alarm_statuses()
        for alarm_status in alarm_statuses:
            print(alarm_status.name)
    """
    alarm_statusess_ = alarmStatuses.execute(client, first=PAGINATION_STEP)
    edges = alarm_statusess_.edges if alarm_statusess_ else []
    while alarm_statusess_ is not None and alarm_statusess_.pageInfo.hasNextPage:
        alarm_statusess_ = alarmStatuses.execute(
            client, after=alarm_statusess_.pageInfo.endCursor, first=PAGINATION_STEP
        )
        if alarm_statusess_ is not None:
            edges.extend(alarm_statusess_.edges)

    for edge in edges:
        node = edge.node
        if node is not None:
            yield alarmStatus(
                id=node.id,
                name=node.name,
            )


def remove_alarm_status(client: SymphonyClient, id: str) -> None:
    """This function delete Alarm Status.

    :param name: Alarm Status name
    :type name: :class:`~psym.common.data_class.alarmStatus`
    :rtype: None

    **Example**

    .. code-block:: python

        remove_alarm_status=client.remove_alarm_status(id=123456789)
    """
    removeAlarmStatus.execute(client, id=id)
